@@ -18,7 +18,7 @@ use Rewire::Engine;
 
 with 'Data::Object::Role::Buildable';
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 # BUILD
 
@@ -111,7 +111,7 @@ method validate() {
 
 =head1 NAME
 
-Rewire
+Rewire - Dependency Injection
 
 =cut
 
@@ -484,7 +484,9 @@ C<metadata> attributes.
   process(Str $name, Any $argument, Maybe[Str] $argument_as) : Any
 
 The process method processes and returns an object or value based on the
-service named but where the arguments are provided ad-hoc.
+service named but where the arguments are provided ad-hoc. B<Note:> This method
+is meant to be used to construct services ad-hoc and as such bypasses caching
+and lifecycle effects.
 
 =over 4
 
@@ -532,7 +534,9 @@ service named but where the arguments are provided ad-hoc.
   resolve(Str $name) : Any
 
 The resolve method resolves and returns an object or value based on the service
-named.
+named. B<Note:> This method is recommended to be used to construct services as
+defined by the configuration and as such doesn't not allow passing additional
+arguments.
 
 =over 4
 
@@ -544,6 +548,30 @@ named.
 
 =back
 
+=over 4
+
+=item resolve example #2
+
+  use Rewire;
+
+  my $services = {
+    mojo_log => {
+      package => 'Mojo/Log',
+      argument => {
+        level => 'fatal',
+        path => '/var/log/rewire.log'
+      },
+    }
+  };
+
+  my $rewire = Rewire->new(
+    services => $services,
+  );
+
+  $rewire->resolve('mojo_log');
+
+=back
+
 =cut
 
 =head2 validate
